{# -*- mode:web -*- engine:django -*- #}
{% comment %}
View template for dialogs that load this template, a complete <html> document,
into an <iframe> dialog content.  The dialog is created within the document
containing the dialog-anchor.

This template includes media for any dialog_anchors included with the form and
the dialog form itself.

This file is part of a program "django-dialogform", a django app to load and open form views
within <dialog> html element popups.

Copyright (C) 2023, Zoltan Kemenczy

This program comes with ABSOLUTELY NO WARRANTY; This is free software, and you are welcome
to redistribute it under conditions of the GPLv3 LICENSE included in this package
To use it, refer to the included README.rst
{% endcomment %}
{% load static %}
<!DOCTYPE html>
<html>
  <head>
    <meta http-equiv="Content-Style-Type" content="text/css"/>
    {% block dialog-media %}
    {{ form.media }}
    {% include "dialogform/anchor_media.html" %}{# in case form refers to dialog-anchors #}
    {% endblock %}
  </head>
  <body style="margin:0">
    <div class="dialogform-dialog">
      {% block dialog-content %}
        {% include "dialogform/form.html" %}
      {% endblock %}
    </div>
  </body>
</html>
