{# -*- mode:web -*- engine:django -*- #}
{% extends "admin/change_form.html" %}
<meta itemprop="this is admin_note_change.html">
{# Eliminate non-form page elements #}
{% block header %}{% endblock %}
{% block nav-breadcrumbs %}{% endblock %}
{% block nav-sidebar %}{% endblock %}

{% block content %}
  <div class="dialogform-dialog">
    {{ block.super }}
  </div>
{% endblock %}

{% block submit_buttons_top %}
  <div class="dialogform-buttons">
    <button class="dialogform" value="cancel">Cancel</button>
    <button class="dialogform" value="confirm">OK</button>
  </div>
{% endblock %}
{% block submit_buttons_bottom %}
  <div class="dialogform-buttons">
    <button class="dialogform" value="cancel">Cancel</button>
    <button class="dialogform" value="confirm">OK</button>
  </div>
{% endblock %}
