/*
  This file is part of a program "django-dialogform", a django app to load and open form views
  within <dialog> html element popups.

  Copyright (C) 2023, Zoltan Kemenczy

  This program comes with ABSOLUTELY NO WARRANTY; This is free software, and you are welcome
  to redistribute it under conditions of the GPLv3 LICENSE included in this package
  To use it, refer to the included README.rst
*/

/*
 * Dialogdemo styles
 */
@media (prefers-color-scheme: light) {
    :root {
        --_dialog-background:       var(--dialog-background, var(--body-bg, #FFFEF8));
        --_dialog-color:            var(--dialog-color,      var(--body-fg, #002040));
        --_dialog-background-hover: var(--dialog-background-hover,          #E8DCC8);
    }
    sup {
        font-size: smaller;
        color: #BA0;
    }
    a {
        color: #A0A;
    }
}
@media (prefers-color-scheme: dark) {
    :root {
        --_dialog-background:       var(--dialog-background, var(--body-bg, #162432));
        --_dialog-color:            var(--dialog-color,      var(--body-fg, #FAEBD7));
        --_dialog-background-hover: var(--dialog-background-hover,          #404040);
    }
    sup {
        font-size: smaller;
        color: #CC0;
    }
    a {
        color: #F8F;
    }
}
html {
    font-family: Arial, Helvetica, sans-serif;
    background: var(--_dialog-background); /* from dialogform */
    color:      var(--_dialog-color);
}

div.noteandtags {
    font-size: 1rem;
}

input, textarea, select, button {
    background: var(--_dialog-background); /* from dialogform */
    color:      var(--_dialog-color);
}

td {
    padding: 0.25em 1em;
    vertical-align: inherit;
}

label {
    padding: 1px;
}
legend {
    padding: 4px;
}

form div {
    padding: 8px 0;
}
