{# -*- mode:web -*- engine:django -*- #}
{% load static %}
<link rel="stylesheet" href="{% static 'dialogform/css/dialogform.css' %}">
<script type="text/javascript" src="{% static 'dialogform/js/dialogform.js' %}"></script>
