{# -*- mode:web -*- engine:django -*- #}
{% comment %}
Dialogform View template for dialog forms created within the same document where the
dialog_anchor(s) are

This file is part of a program "django-dialogform", a django app to load and open form views
within <dialog> html element popups.

Copyright (C) 2023, Zoltan Kemenczy

This program comes with ABSOLUTELY NO WARRANTY; This is free software, and you are welcome
to redistribute it under conditions of the GPLv3 LICENSE included in this package
To use it, refer to the included README.rst
{% endcomment %}

<dialog {% if dialogform_id %}id="{{ dialogform_id }}"{% endif %} class="dialogform-dialog">
  <div class="dialogform-content">
    {% block dialog-content %}
      {% include "dialogform/form.html" %}
    {% endblock %}
  </div>
  <div class="dialogform-media">
    {% block dialog-media %}
      {{ form.media }}
    {% endblock %}
  </div>
</dialog>
